/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

// ==============================
// ! Scriptability related code !
// ==============================

/////////////////////////////////////////////////////
//
// This file implements the nsScriptablePeer object
// The native methods of this class are supposed to
// be callable from JavaScript
//
#include "plugin.h"

static NS_DEFINE_IID(kIScriptableIID, NS_ISPICEC_IID);
static NS_DEFINE_IID(kIClassInfoIID, NS_ICLASSINFO_IID);
static NS_DEFINE_IID(kISupportsIID, NS_ISUPPORTS_IID);

nsScriptablePeer::nsScriptablePeer(nsPluginInstance* aPlugin)
{
  mPlugin = aPlugin;
  mRefCnt = 0;
}

nsScriptablePeer::~nsScriptablePeer()
{
}

// AddRef, Release and QueryInterface are common methods and must 
// be implemented for any interface
NS_IMETHODIMP_(nsrefcnt) nsScriptablePeer::AddRef() 
{ 
  ++mRefCnt; 
  return mRefCnt; 
} 

NS_IMETHODIMP_(nsrefcnt) nsScriptablePeer::Release() 
{ 
  --mRefCnt; 
  if (mRefCnt == 0) { 
    delete this;
    return 0; 
  } 
  return mRefCnt; 
} 

// here nsScriptablePeer should return three interfaces it can be asked for by their iid's
// static casts are necessary to ensure that correct pointer is returned
NS_IMETHODIMP nsScriptablePeer::QueryInterface(const nsIID& aIID, void** aInstancePtr) 
{ 
  if(!aInstancePtr) 
    return NS_ERROR_NULL_POINTER; 

  if(aIID.Equals(kIScriptableIID)) {
    *aInstancePtr = static_cast<nsISpicec*>(this); 
    AddRef();
    return NS_OK;
  }

  if(aIID.Equals(kIClassInfoIID)) {
    *aInstancePtr = static_cast<nsIClassInfo*>(this); 
    AddRef();
    return NS_OK;
  }

  if(aIID.Equals(kISupportsIID)) {
    *aInstancePtr = static_cast<nsISupports*>(static_cast<nsISpicec*>(this)); 
    AddRef();
    return NS_OK;
  }

  return NS_NOINTERFACE; 
}

void nsScriptablePeer::SetInstance(nsPluginInstance* plugin)
{
  mPlugin = plugin;
}

//
// the following methods will be callable from JavaScript
//
NS_IMETHODIMP nsScriptablePeer::Connect()
{
  if (mPlugin)
    mPlugin->Connect();

  return NS_OK;
}

NS_IMETHODIMP nsScriptablePeer::Disconnect()
{
  if (mPlugin)
    mPlugin->disconnect();

  return NS_OK;
}

NS_IMETHODIMP nsScriptablePeer::Show()
{
  if (mPlugin)
    mPlugin->show();

  return NS_OK;
}

NS_IMETHODIMP nsScriptablePeer::ConnectedStatus(PRInt32 *_retval) {
  if (mPlugin)
    mPlugin->ConnectedStatus(_retval);

  return NS_OK;
}

NS_IMETHODIMP nsScriptablePeer::SetLanguageStrings(const char * aSection, const char * aLanguage) {
    if (mPlugin) {
        mPlugin->SetLanguageStrings(aSection, aLanguage);
    }

  return NS_OK;
}

NS_IMETHODIMP nsScriptablePeer::SetUsbFilter(const char * aUsbFilter) {
    if (mPlugin) {
        mPlugin->SetUsbFilter(aUsbFilter);
    }
    
    return NS_OK;
}

/* attribute ing Host; */
NS_IMETHODIMP nsScriptablePeer::GetHostIP(char * *aHost) {
    if (mPlugin)
        mPlugin->GetHostIP(aHost);

    return NS_OK;
}
NS_IMETHODIMP nsScriptablePeer::SetHostIP(const char * aHost) {
    if (mPlugin) {
        mPlugin->SetHostIP(aHost);
        return NS_OK;
    } else {
        return NS_ERROR_NULL_POINTER;
    }
}

/* attribute ing Port; */
NS_IMETHODIMP nsScriptablePeer::GetPort(char * *aPort) {
    if (mPlugin)
        mPlugin->GetPort(aPort);

    return NS_OK;
}
NS_IMETHODIMP nsScriptablePeer::SetPort(const char * aPort) {
    if (mPlugin) {
        mPlugin->SetPort(aPort);
        return NS_OK;
    } else {
        return NS_ERROR_NULL_POINTER;
    }
}

/* attribute ing Password; */
NS_IMETHODIMP nsScriptablePeer::GetPassword(char * *aPassword) {
    if (mPlugin)
        mPlugin->GetPassword(aPassword);

    return NS_OK;
}
NS_IMETHODIMP nsScriptablePeer::SetPassword(const char * aPassword) {
    if (mPlugin) {
        mPlugin->SetPassword(aPassword);
        return NS_OK;
    } else {
        return NS_ERROR_NULL_POINTER;
    }
}

/* attribute ing CipherSuite; */
NS_IMETHODIMP nsScriptablePeer::GetCipherSuite(char * *aCipherSuite) {
    if (mPlugin)
        mPlugin->GetCipherSuite(aCipherSuite);

    return NS_OK;
}
NS_IMETHODIMP nsScriptablePeer::SetCipherSuite(const char * aCipherSuite) {
    if (mPlugin) {
        mPlugin->SetCipherSuite(aCipherSuite);
        return NS_OK;
    } else {
        return NS_ERROR_NULL_POINTER;
    }
}

/* attribute ing SSLChannels; */
NS_IMETHODIMP nsScriptablePeer::GetSSLChannels(char * *aSSLChannels) {
    if (mPlugin)
        mPlugin->GetSSLChannels(aSSLChannels);

    return NS_OK;
}
NS_IMETHODIMP nsScriptablePeer::SetSSLChannels(const char * aSSLChannels) {
    if (mPlugin) {
        mPlugin->SetSSLChannels(aSSLChannels);
        return NS_OK;
    } else {
        return NS_ERROR_NULL_POINTER;
    }
}

/* attribute ing TrustStore */
NS_IMETHODIMP nsScriptablePeer::GetTrustStore(char * *aTrustStore) {
    if (mPlugin)
        mPlugin->GetTrustStore(aTrustStore);

    return NS_OK;
}
NS_IMETHODIMP nsScriptablePeer::SetTrustStore(const char * aTrustStore) {
    if (mPlugin) {
        mPlugin->SetTrustStore(aTrustStore);
        return NS_OK;
    } else {
        return NS_ERROR_NULL_POINTER;
    }
}

/* attribute ing HostSubject; */
NS_IMETHODIMP nsScriptablePeer::GetHostSubject(char * *aHostSubject) {
    if (mPlugin)
        mPlugin->GetHostSubject(aHostSubject);

    return NS_OK;
}
NS_IMETHODIMP nsScriptablePeer::SetHostSubject(const char * aHostSubject) {
    if (mPlugin) {
        mPlugin->SetHostSubject(aHostSubject);
        return NS_OK;
    } else {
        return NS_ERROR_NULL_POINTER;
    }
}

/* attribute ing FullScreen; */
NS_IMETHODIMP nsScriptablePeer::GetFullScreen(PRBool *aFullScreen) {
    if (mPlugin)
        mPlugin->GetFullScreen(aFullScreen);

    return NS_OK;
}
NS_IMETHODIMP nsScriptablePeer::SetFullScreen(PRBool aFullScreen) {
    if (mPlugin) {
        mPlugin->SetFullScreen(aFullScreen);
        return NS_OK;
    } else {
        return NS_ERROR_NULL_POINTER;
    }
}

/* attribute ing FullScreen; */
NS_IMETHODIMP nsScriptablePeer::GetTitle(char * *aTitle) {
    if (mPlugin)
        mPlugin->GetTitle(aTitle);

    return NS_OK;
}
NS_IMETHODIMP nsScriptablePeer::SetTitle(const char * aTitle) {
    if (mPlugin) {
        mPlugin->SetTitle(aTitle);
        return NS_OK;
    } else {
        return NS_ERROR_NULL_POINTER;
    }
}

/* attribute ing SecurePort; */
NS_IMETHODIMP nsScriptablePeer::GetSecurePort(char * *aSecurePort) {
    if (mPlugin)
        mPlugin->GetSecurePort(aSecurePort);

    return NS_OK;
}
NS_IMETHODIMP nsScriptablePeer::SetSecurePort(const char * aSecurePort) {
    if (mPlugin) {
        mPlugin->SetSecurePort(aSecurePort);
        return NS_OK;
    } else {
        return NS_ERROR_NULL_POINTER;
    }
}

/* attribute ing dynamicMenu; */
NS_IMETHODIMP nsScriptablePeer::GetDynamicMenu(char * *adynamicMenu) {
    if (mPlugin)
        mPlugin->GetDynamicMenu(adynamicMenu);

    return NS_OK;
}
NS_IMETHODIMP nsScriptablePeer::SetDynamicMenu(const char * adynamicMenu) {
    if (mPlugin) {
        mPlugin->SetDynamicMenu(adynamicMenu);
        return NS_OK;
    } else {
        return NS_ERROR_NULL_POINTER;
    }
}

/* attribute ing NumberOfMonitors; */
NS_IMETHODIMP nsScriptablePeer::GetNumberOfMonitors(char * *aNumberOfMonitors) {
    if (mPlugin)
        mPlugin->GetNumberOfMonitors(aNumberOfMonitors);

    return NS_OK;
}
NS_IMETHODIMP nsScriptablePeer::SetNumberOfMonitors(const char * aNumberOfMonitors) {
    if (mPlugin) {
        mPlugin->SetNumberOfMonitors(aNumberOfMonitors);
        return NS_OK;
    } else {
        return NS_ERROR_NULL_POINTER;
    }
}

/* attribute ing AdminConsole; */
NS_IMETHODIMP nsScriptablePeer::GetAdminConsole(PRBool *aAdminConsole) {
    if (mPlugin)
        mPlugin->GetAdminConsole(aAdminConsole);

    return NS_OK;
}
NS_IMETHODIMP nsScriptablePeer::SetAdminConsole(PRBool aAdminConsole) {
    if (mPlugin) {
        mPlugin->SetAdminConsole(aAdminConsole);
        return NS_OK;
    } else {
        return NS_ERROR_NULL_POINTER;
    }
}

/* attribute ing GuestHostName; */
NS_IMETHODIMP nsScriptablePeer::GetGuestHostName(char * *aGuestHostName) {
    if (mPlugin)
        mPlugin->GetGuestHostName(aGuestHostName);

    return NS_OK;
}
NS_IMETHODIMP nsScriptablePeer::SetGuestHostName(const char * aGuestHostName) {
    if (mPlugin) {
        mPlugin->SetGuestHostName(aGuestHostName);
        return NS_OK;
    } else {
        return NS_ERROR_NULL_POINTER;
    }
}

/* attribute ing HotKeys; */
NS_IMETHODIMP nsScriptablePeer::GetHotKey(char * *aHotKeys) {
    if (mPlugin)
	mPlugin->GetHotKeys(aHotKeys);

    return NS_OK;
}
NS_IMETHODIMP nsScriptablePeer::SetHotKey(const char * aHotKeys) {
    if (mPlugin) {
	mPlugin->SetHotKeys(aHotKeys);
	return NS_OK;
    } else {
	return NS_ERROR_NULL_POINTER;
    }
}

/* attribute ing NoTaskMgrExecution; */
NS_IMETHODIMP nsScriptablePeer::GetNoTaskMgrExecution(PRBool *aNoTaskMgrExecution) {
    if (mPlugin)

        mPlugin->GetNoTaskMgrExecution(aNoTaskMgrExecution);

    return NS_OK;
}
NS_IMETHODIMP nsScriptablePeer::SetNoTaskMgrExecution(PRBool aNoTaskMgrExecution) {
    if (mPlugin) {
        mPlugin->SetNoTaskMgrExecution(aNoTaskMgrExecution);
        return NS_OK;
    } else {
        return NS_ERROR_NULL_POINTER;
    }
}

/* attribute ing SendCtrlAltdelete; */
NS_IMETHODIMP nsScriptablePeer::GetSendCtrlAltdelete(PRBool *aSendCtrlAltdelete) {
    if (mPlugin)
        mPlugin->GetSendCtrlAltdelete(aSendCtrlAltdelete);

    return NS_OK;
}
NS_IMETHODIMP nsScriptablePeer::SetSendCtrlAltdelete(PRBool aSendCtrlAltdelete) {
    if (mPlugin) {
        mPlugin->SetSendCtrlAltdelete(aSendCtrlAltdelete);
        return NS_OK;
    } else {
        return NS_ERROR_NULL_POINTER;
    }
}

/* attribute unsigned short UsbListenPort; */
NS_IMETHODIMP nsScriptablePeer::GetUsbListenPort(unsigned short *aUsbPort) {
    if (mPlugin) {
        mPlugin->GetUsbListenPort(aUsbPort);
    }
    
    return NS_OK;
}

NS_IMETHODIMP nsScriptablePeer::SetUsbListenPort(unsigned short aUsbPort) {
    if (mPlugin) {
        mPlugin->SetUsbListenPort(aUsbPort);
    }
    
    return NS_OK;
}

/* attribute boolean UsbAutoShare; */
NS_IMETHODIMP nsScriptablePeer::GetUsbAutoShare(PRBool *aUsbAutoShare) {
    if (mPlugin) {
        mPlugin->GetUsbAutoShare(aUsbAutoShare);
    }
    
    return NS_OK;
}

NS_IMETHODIMP nsScriptablePeer::SetUsbAutoShare(PRBool aUsbAutoShare) {
    if (mPlugin) {
        mPlugin->SetUsbAutoShare(aUsbAutoShare);
    }
    
    return NS_OK;
}
